from django.shortcuts import render
from django.template import RequestContext

from . import utils
from . import app_settings


class Plugin(object):
    def get_before_urls(self):
        from . import urls
        return urls.urlpatterns

    def get_apps(self):
        return [__name__]

    def get_authentication_backends(self):
        return ['authentic2_auth_fc.backends.FcBackend']

    def get_auth_frontends(self):
        return ['authentic2_auth_fc.auth_frontends.FcFrontend']

    def redirect_logout_list(self, request, next=None):
        url = utils.build_logout_url(request, next)
        # url is assumed empty if no active session on the OP.
        if url:
            return [url]
        return []

    def registration_form_prefill(self, request):
        if app_settings.enable_registration_form_prefill:
            return [utils.get_mapped_attributes(request)]
        return []

    def registration_frontend(self, request, *args, **kwargs):
        if 'fc-user_info' in request.session:
            return []
        context_instance = kwargs.get('context_instance', RequestContext(request))
        tpl_parameters = {'about_url': app_settings.about_url}
        tpl_parameters['registration'] = True
        return render(request, 'authentic2_auth_fc/login.html',
                      tpl_parameters, context_instance=context_instance)
