from django.utils.translation import gettext_noop
from django.template.loader import render_to_string
from django.template import RequestContext
from django.shortcuts import render

from authentic2 import app_settings as a2_app_settings

from . import app_settings


class FcFrontend(object):
    def enabled(self):
        return app_settings.enable

    def name(self):
        return gettext_noop('FranceConnect')

    def id(self):
        return 'fc'

    def login(self, request, *args, **kwargs):
        if 'nofc' in request.GET:
            return
        tpl_parameters = {'about_url': app_settings.about_url}
        if 'fc-user_info' in request.session:
            tpl_parameters['fc_user_info'] = request.session['fc-user_info']
        context_instance = kwargs.pop('context_instance', None)
        return render(request, 'authentic2_auth_fc/login.html',
                      tpl_parameters, context_instance=context_instance)

    def profile(self, request, *args, **kwargs):
        unlink = False
        # We prevent unlinking if the user has no usable password and can't change it
        # because we assume that the password is the unique other mean of authentication
        # and unlinking would make the account unreachable.
        if request.user.has_usable_password() or \
                a2_app_settings.A2_REGISTRATION_CAN_CHANGE_PASSWORD:
            # Hide the link to the unlinking view.
            unlink = True
        context_instance = kwargs.pop('context_instance', None) or RequestContext(request)
        return render_to_string('authentic2_auth_fc/linking.html',
                {'popup': True, 'unlink' : unlink,
                    'about_url': app_settings.about_url},
                context_instance=context_instance)
